set_dimension_type_conformed: Set the type of a conformed dimension
Description
It allows us to define the type of a conformed dimension.
Usage
set_dimension_type_conformed(dimension)# S3 method for dimension_table
set_dimension_type_conformed(dimension)
Arguments
dimension
A dimension_table object.
Value
A dimension_table object.
Details
Attributes can be accessed directly but this function has been defined
because it is used from other classes and is thus done in a more controlled
way.