star_schema_as_tl: Export a star schema as a tibble list (common)
Description
Export a star schema as a tibble list (common)
Usage
star_schema_as_tl(st, tl_prev = NULL, commondim = NULL, include_role_playing)# S3 method for star_schema
star_schema_as_tl(st, tl_prev = NULL, commondim = NULL, include_role_playing)
Arguments
- st
A star_schema object.
- tl_prev
A list of tibble objects.
- commondim
A list of dimension names already included.
- include_role_playing
A boolean.